@@ -29,6 +29,8 @@ from common.account import Account
 
 class Keyring:
 	def __init__(self):
+		self.KEYRING_ITEM_NAME = 'Mailnag password for %s://%s@%s'
+		
 		(result, kr_name) = GnomeKeyring.get_default_keyring_sync()
 		self._defaultKeyring = kr_name
 		
@@ -41,7 +43,8 @@ class Keyring:
 			raise Exception('Failed to unlock default keyring')
 
 
-	def get(self, protocol, user, server):								# get password for account from Gnome Keyring
+	# get password for account from Gnome Keyring
+	def get(self, protocol, user, server):
 		(result, ids) = GnomeKeyring.list_item_ids_sync(self._defaultKeyring)		
 		if result == GnomeKeyring.Result.OK:
 			displayNameDict = {}
@@ -49,9 +52,9 @@ class Keyring:
 				(result, item) = GnomeKeyring.item_get_info_sync(self._defaultKeyring, identity)
 				displayNameDict[item.get_display_name()] = identity
 
-			if 'Mailnag password for %s://%s@%s' % (protocol, user, server) in displayNameDict:
+			if self.KEYRING_ITEM_NAME % (protocol, user, server) in displayNameDict:
 				(result, item) = GnomeKeyring.item_get_info_sync(self._defaultKeyring, \
-					displayNameDict['Mailnag password for %s://%s@%s' % \
+					displayNameDict[self.KEYRING_ITEM_NAME % \
 					(protocol, user, server)])
 
 				if item.get_secret() != '':
@@ -65,11 +68,12 @@ class Keyring:
 				return ''
 
 		else:
-			# DEBUG print "Keyring.get(): Either default- nor 'login'-Keyring available."
+			# DEBUG print "Keyring.get(): Neither default- nor 'login'-Keyring available."
 			return ''
 
 
-	def set(self, protocol, user, server, password): # store password in Gnome-Keyring
+	# store password in Gnome-Keyring
+	def set(self, protocol, user, server, password):
 		if password != '':
 			displayNameDict = {}
 			(result, ids) = GnomeKeyring.list_item_ids_sync(self._defaultKeyring)
@@ -83,32 +87,35 @@ class Keyring:
 			GnomeKeyring.Attribute.list_append_string(attrs, 'user',		user)
 			GnomeKeyring.Attribute.list_append_string(attrs, 'server',		server)
 			
-			if 'Mailnag password for %s://%s@%s' % (protocol, user, server) in displayNameDict:
+			if self.KEYRING_ITEM_NAME % (protocol, user, server) in displayNameDict:
 				(result, item) = GnomeKeyring.item_get_info_sync(self._defaultKeyring, \
-					displayNameDict['Mailnag password for %s://%s@%s' % \
+					displayNameDict[self.KEYRING_ITEM_NAME % \
 					(protocol, user, server)])
 				
 				if password != item.get_secret():
 					GnomeKeyring.item_create_sync(self._defaultKeyring, \
 						GnomeKeyring.ItemType.GENERIC_SECRET, \
-						'Mailnag password for %s://%s@%s' % (protocol, user, server), \
+						self.KEYRING_ITEM_NAME % (protocol, user, server), \
 						attrs, password, True)
 			else:
 				GnomeKeyring.item_create_sync(self._defaultKeyring, \
 					GnomeKeyring.ItemType.GENERIC_SECRET, \
-					'Mailnag password for %s://%s@%s' % (protocol, user, server), \
+					self.KEYRING_ITEM_NAME % (protocol, user, server), \
 					attrs, password, True)
 
 
-	def remove(self, accounts):											# delete obsolete entries from Keyring
+	# delete obsolete entries from Keyring
+	def remove(self, accounts):
+		# create list of all valid accounts
 		valid_accounts = []
-		for acc in accounts:											# create list of all valid accounts
+		for acc in accounts:
 			protocol = 'imap' if acc.imap else 'pop'
-			valid_accounts.append('Mailnag password for %s://%s@%s' % \
+			valid_accounts.append(self.KEYRING_ITEM_NAME % \
 			(protocol, acc.user, acc.server))
 
+		# find and delete invalid entries
 		(result, ids) = GnomeKeyring.list_item_ids_sync(self._defaultKeyring)
-		if result == GnomeKeyring.Result.OK:				# find and delete invalid entries
+		if result == GnomeKeyring.Result.OK:
 			displayNameDict = {}
 			for identity in ids:
 				(result, item) = GnomeKeyring.item_get_info_sync(self._defaultKeyring, identity)
